@@ -87,8 +87,39 @@ class DataVolume(NamespacedResource):
         yaml_file=None,
         delete_timeout=TIMEOUT_4MINUTES,
         api_name="pvc",
+        delete_after_completion=None,
         **kwargs,
     ):
+        """
+        DataVolume object
+
+        Args:
+            name (str): DataVolume name.
+            namespace (str): DataVolume namespace.
+            source (str): source of DV - upload/http/pvc/registry.
+            size (str): DataVolume size - format size+size unit, for example: "5Gi".
+            storage_class (str, default: None): storage class name for DataVolume.
+            url (str, default: None): url for importing DV, when source is http/registry.
+            content_type (str, default: "kubevirt"): DataVolume content type.
+            access_modes (str, default: None): DataVolume access mode.
+            cert_configmap (str, default: None): name of config map for TLS certificates.
+            secret (Secret, default: None): to be set as secretRef.
+            client (DynamicClient): DynamicClient to use.
+            volume_mode (str, default: None): DataVolume volume mode.
+            hostpath_node (str, default: None): Node name to provision the DV on.
+            source_pvc (str, default: None): PVC name for when cloning the DV.
+            source_namespace (str, default: None): PVC namespace for when cloning the DV.
+            multus_annotation (str, default: None): network nad name.
+            bind_immediate_annotation (bool, default: None): when WaitForFirstConsumer is set in  StorageClass and DV
+            should be bound immediately.
+            preallocation (bool, default: None): preallocate disk space.
+            teardown (bool, default: True): Indicates if this resource would need to be deleted.
+            privileged_client (DynamicClient, default: None): Instance of Dynamic client
+            yaml_file (yaml, default: None): yaml file for the resource.
+            delete_timeout (int, default: 4 minutes): timeout associated with delete action.
+            api_name (str, default: "pvc"): api used for DV, pvc/storage
+            delete_after_completion (str, default: None): annotation for garbage collector - "true"/"false"
+        """
         super().__init__(
             name=name,
             namespace=namespace,
@@ -115,6 +146,7 @@ class DataVolume(NamespacedResource):
         self.bind_immediate_annotation = bind_immediate_annotation
         self.preallocation = preallocation
         self.api_name = api_name
+        self.delete_after_completion = delete_after_completion
 
     def to_dict(self):
         super().to_dict()
@@ -161,9 +193,7 @@ class DataVolume(NamespacedResource):
                 )
             if self.bind_immediate_annotation:
                 self.res["metadata"].setdefault("annotations", {}).update(
-                    {
-                        f"{NamespacedResource.ApiGroup.CDI_KUBEVIRT_IO}/storage.bind.immediate.requested": "true"
-                    }
+                    {f"{self.api_group}/storage.bind.immediate.requested": "true"}
                 )
             if self.source == "pvc":
                 self.res["spec"]["source"]["pvc"] = {
@@ -172,6 +202,12 @@ class DataVolume(NamespacedResource):
                 }
             if self.preallocation is not None:
                 self.res["spec"]["preallocation"] = self.preallocation
+            if self.delete_after_completion:
+                self.res["metadata"].setdefault("annotations", {}).update(
+                    {
+                        f"{self.api_group}/storage.deleteAfterCompletion": self.delete_after_completion
+                    }
+                )
 
     def wait_deleted(self, timeout=TIMEOUT_4MINUTES):
         """
@@ -214,17 +250,62 @@ class DataVolume(NamespacedResource):
     def _check_none_pending_status(self, failure_timeout=120):
         # Avoid waiting for "Succeeded" status if DV's in Pending/None status
         sample = None
+        # if garbage collector is enabled, DV will be deleted after success
         try:
             for sample in TimeoutSampler(
                 wait_timeout=failure_timeout,
                 sleep=10,
-                func=lambda: self.instance.status.phase,
+                func=lambda: self.exists,
             ):
                 # If DV status is Pending (or Status is not yet updated) continue to wait, else exit the wait loop
-                if sample in [self.Status.PENDING, None]:
+                if sample and (
+                    not sample.status
+                    or sample.status.phase
+                    in [
+                        self.Status.PENDING,
+                        None,
+                    ]
+                ):
                     continue
-                else:
-                    break
+                break
         except TimeoutExpiredError:
             self.logger.error(f"{self.name} status is {sample}")
             raise
+
+    def wait_for_dv_success(self, timeout=600, failure_timeout=120):
+        self.logger.info(f"Wait DV success for {timeout} seconds")
+        self._check_none_pending_status(failure_timeout=failure_timeout)
+        self.pvc.wait_for_status(
+            status=PersistentVolumeClaim.Status.BOUND, timeout=timeout
+        )
+        # if garbage collector enabled, the DV deleted once succeeded
+        try:
+            for sample in TimeoutSampler(
+                sleep=1,
+                wait_timeout=timeout,
+                func=lambda: self.exists,
+            ):
+                # DV reach to success if the status is succeeded or if the DV does not exists
+                if sample is None or sample.status.phase == self.Status.SUCCEEDED:
+                    return
+        except TimeoutExpiredError:
+            self.logger.error(f"Status of {self.kind} {self.name} is {sample}")
+            raise
+
+    def delete(self, wait=False, timeout=TIMEOUT_4MINUTES, body=None):
+        """
+        Delete DataVolume
+
+        Args:
+            wait (bool): True to wait for DataVolume and PVC to be deleted.
+            timeout (int): Time to wait for resources deletion
+            body (dict): Content to send for delete()
+
+        Returns:
+            bool: True if delete succeeded, False otherwise.
+        """
+        # if garbage collector is enabled, DV will be deleted after success
+        if self.exists:
+            return super().delete(wait=wait, timeout=timeout, body=body)
+        else:
+            return self.pvc.delete(wait=wait, timeout=timeout, body=body)
