@@ -8,4 +8,4 @@ class VirtualService(NamespacedResource):
     Virtual Service object.
     """
 
-    api_version = NamespacedResource.ApiGroup.NETWORKING_ISTIO_IO
+    api_group = NamespacedResource.ApiGroup.NETWORKING_ISTIO_IO
